@@ -4,7 +4,7 @@
 pub(crate) mod feature_cfg;
 
 #[macro_use]
-pub mod generate_fn_macro;
+pub(crate) mod generate_fn_macro;
 
 pub use create_async_fn_body;
 
